<template>
  <div class="bbsl-common-page"
       @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam"
               :inline="true">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="预案标题：">
              <el-input maxlength="15"
                        size="mini"
                        placeholder="请输入预案标题"
                        v-model="queryParam.params.planTitle"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="行政区划">
              <el-cascader filterable
                           size="mini"
                           :show-all-levels="false"
                           :options="basAdNames"
                           v-model="queryParam.params.addvcd"
                           :props="{value: 'code', label: 'name', children: 'children'}"
                           @change="onhouChange"
                           placeholder="请选择所属行政区划"
                           clearable>
                <template slot-scope="{node, data}">
                  <span>{{ data.name }}</span>
                  <span v-if="!node.isLeaf">
                    ({{ data.children === [] ? '' : data.children.length }})
                  </span>
                </template>
              </el-cascader>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item>
              <el-button type="primary"
                         icon="el-icon-search"
                         size="mini"
                         @click="onClickSearch">搜索</el-button>
              <el-button icon="el-icon-refresh"
                         size="mini"
                         @click="resetQuery">重置</el-button>
              <!-- <el-button type="text" @click.stop="openMore"
                >更多
                <i
                  :class="showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'"
                ></i
              ></el-button> -->
            </el-form-item>
          </el-col>
        </el-row>
        <!-- <div class="bbsl-search-more" style="width:250px" v-if="showMore">
          <el-row>
          </el-row>
        </div> -->
      </el-form>
    </div>
    <div class="bbsl-table-content"
         ref="contentPanel">
      <div class="bbsl-btn-content"
           ref="btnPanel">
        <el-button size="mini"
                   icon="el-icon-plus"
                   type="primary"
                   @click="openFormDiao">新增</el-button>
        <el-button :disabled="!multipleSelection.length"
                   size="mini"
                   icon="el-icon-delete"
                   type="danger"
                   @click="deleteSelect">删除</el-button>
      </div>
      <el-table stripe
                size="mini"
                :height="tableMaxHeight"
                @row-dblclick="handleDbClick"
                :style="{width: '100%'}"
                ref="multipleSelection"
                v-loading="loading"
                border
                :data="tableData"
                :row-key="getRowKey"
                @selection-change="handleSelectionChange"
                :header-cell-style="{'text-align': 'center'}"
                :cell-style="{'text-align': 'center'}">
        <el-table-column type="selection"
                         width="55"
                         :reserve-selection="true"></el-table-column>
        <el-table-column fixed
                         sortable
                         prop="planTitle"
                         label="预案标题"
                         show-overflow-tooltip></el-table-column>
        <el-table-column sortable
                         prop="addvcdName"
                         label="行政区划"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable
                         prop="weaveCompany"
                         label="编制单位"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable
                         prop="weaveDate"
                         label="编制时间"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable
                         prop="approvalCompany"
                         label="批复单位"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable
                         prop="approvalDate"
                         label="批复时间"
                         show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel"
                     align="right"
                     class="bbsl-pagination"
                     background
                     @size-change="handleSizeChange"
                     @current-change="handleCurrentChange"
                     :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30, 40, 50]"
                     :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper"
                     :total="total"></el-pagination>
    </div>
    <form-dialog v-if="showFormDia"
                 @closeFormDiao="closeFormDiao"
                 @refList="getDateList"
                 :showFormDia="showFormDia"
                 :title="title"
                 :pId="pId"></form-dialog>
  </div>
</template>
<script>
import FormDialog from './components/shFrom-dialog.vue'
import ShPlanManage_manage from '@/api/ShPlanManage.js'
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
export default {
  name: 'ShPlanManage_manage',
  components: {
    FormDialog,
  },
  mixins: [TableMixin],
  data () {
    return {
      loading: false,
      multipleSelection: [], // 复选框
      queryParam: {
        pageBean: {
          pageSize: 20,
          page: 1,
        },
        params: {
          planTitle: null, //名称
          addvcd: null
        },
      },
      total: 0,
      title: '',
      showFormDia: false,
      tableData: [],
      pId: '',
      basAdNames: [], //行政区
    }
  },
  created () {
    this.getDateList()
    ShPlanManage_manage.getbasAdName({}, res => {
      this.basAdNames = res.value
    })
  },
  methods: {
    onhouChange (val) {
      if (val) {
        this.queryParam.params.addvcd = val.pop().toString()
        console.log(this.queryParam.params.addvcd);

      } else {
        this.queryParam.params.addvcd = null;
      }
    },

    getDateList () {
      this.loading = true
      this.tableData = []
      ShPlanManage_manage.ListGet(this.queryParam, (res) => {
        if (res.state) {
          this.tableData = res.value.rows;
          this.total = res.value.total
          this.loading = false
        } else {
          this.$message(res.message)
        }
      })
    },
    openFormDiao () {
      this.title = '新增'
      this.showFormDia = true;
    },
    closeFormDiao () {
      this.showFormDia = false;
      this.getDateList()
    },
    handleSizeChange (val) {
      this.queryParam.pageBean.pageSize = val;
      this.getDateList()
    },
    handleCurrentChange (val) {
      this.queryParam.pageBean.page = val;
      this.getDateList()
    },
    // // 修改
    handleUpdate (row) {
      this.title = '修改'
      this.pId = row.id
      this.showFormDia = true
    },
    handleSelectionChange (val) {
      this.multipleSelection = val.map((item) => {
        return item.id
      })
    },
    // // 指定一个key标识这一行的数据
    getRowKey (row) {
      return row.id
    },
    // // 批量删除
    deleteSelect () {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          ShPlanManage_manage
            .remove(this.multipleSelection, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                // this.multipleSelection = [];
                this.$refs.multipleSelection.clearSelection()
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    /** 删除按钮操作 */
    handleDelete (row) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          ShPlanManage_manage.remove(row.id, (res) => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: '删除成功',
                duration: 2000,
                // offset: 80
              })
              this.queryParam.pageBean.page = 1
              this.getDateList()
            }
          })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    // // 点击查询
    onClickSearch () {
      //     this.queryParam.basArea=this.queryParam.basArea;
      //   if (this.queryParam.basArea) {
      //     this.queryParam.basArea = this.queryParam.basArea + 'km2'
      //   } else {
      //     this.queryParam.basArea = null
      //   }
      this.queryParam.pageBean.page = 1
      this.getDateList()
    },
    // 重置
    resetQuery () {
      this.queryParam.params = {}
      this.onClickSearch()
    },
  },
}
</script>
<style lang="scss" scoped>
.btn-content {
  display: flex;
}
.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}
.el-select-dropdown__item {
  color: #9a9a9a !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}
.btn-content :first-child {
  margin: 0 0 0 0 !important;
}
// ::v-deep .el-table__body-wrapper::-webkit-scrollbar {
//   width: 6px;
//   height: 15px;
// }
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}
::-webkit-scrollbar {
  background: #fff !important;
}
.bbsl-pagination {
  bottom: 10px !important;
}
</style>
